@@ -2,19 +2,22 @@ from logging import warn
 import os
 from collections import namedtuple
 import pandas as pd
+import pathlib
 from enum import IntEnum
 import warnings
 import numpy as np
 from datetime import datetime, timedelta
 from scipy.spatial import cKDTree
+import tempfile
 from tqdm import trange
+import typing
 
 from DHI.Generic.MikeZero import eumUnit, eumQuantity
 from DHI.Generic.MikeZero.DFS import DfsFileFactory, DfsFactory
 from DHI.Generic.MikeZero.DFS.dfsu import DfsuFile, DfsuFileType, DfsuBuilder, DfsuUtil
 from DHI.Generic.MikeZero.DFS.mesh import MeshFile, MeshBuilder
 
-from .dutil import get_item_info, get_valid_items_and_timesteps
+from .dfsutil import _get_item_info, _valid_item_numbers, _valid_timesteps
 from .dataset import Dataset
 from .dotnet import (
     to_numpy,
@@ -26,6 +29,7 @@ from .dotnet import (
     asnetarray_v2,
 )
 from .dfs0 import Dfs0
+from .dfs2 import Dfs2
 from .eum import ItemInfo, EUMType, EUMUnit
 from .helpers import safe_length
 from .spatial import Grid2D
@@ -332,7 +336,7 @@ class _UnstructuredGeometry:
                 geom._type = UnstructuredType.Dfsu2D
                 geom._n_layers = None
                 if node_layers == "all":
-                    print(
+                    warnings.warn(
                         "Warning: Only 1 layer in new geometry (hence 2d), but you have kept both top and bottom nodes! Hint: use node_layers='top' or 'bottom'"
                     )
             else:
@@ -1535,8 +1539,7 @@ class _UnstructuredGeometry:
         return np.asarray(elem_table), ec, data
 
     def _get_boundary_polylines_uncategorized(self):
-        """Construct closed polylines for all boundary faces        
-        """
+        """Construct closed polylines for all boundary faces"""
         boundary_faces = self._get_boundary_faces()
         face_remains = boundary_faces.copy()
         polylines = []
@@ -1562,7 +1565,7 @@ class _UnstructuredGeometry:
         return polylines
 
     def _get_boundary_polylines(self):
-        """Get boundary polylines and categorize as inner or outer by 
+        """Get boundary polylines and categorize as inner or outer by
         assessing the signed area
         """
         polylines = self._get_boundary_polylines_uncategorized()
@@ -1594,8 +1597,7 @@ class _UnstructuredGeometry:
         return BoundaryPolylines(n_ext, poly_lines_ext, n_int, poly_lines_int)
 
     def _get_boundary_faces(self):
-        """Construct list of faces
-        """
+        """Construct list of faces"""
         element_table = self.geometry2d.element_table
 
         all_faces = []
@@ -1718,7 +1720,7 @@ class _UnstructuredFile(_UnstructuredGeometry):
 
         # items
         self._n_items = safe_length(dfs.ItemInfo)
-        self._items = get_item_info(dfs, list(range(self._n_items)))
+        self._items = _get_item_info(dfs.ItemInfo, list(range(self._n_items)))
 
         # time
         self._start_time = from_dotnet_datetime(dfs.StartDateTime)
@@ -1870,21 +1872,16 @@ class Dfsu(_UnstructuredFile):
         dfs = DfsuFile.Open(self._filename)
         # time may have changes since we read the header
         # (if engine is continuously writing to this file)
-        self._n_timesteps = dfs.NumberOfTimeSteps
         # TODO: add more checks that this is actually still the same file
         # (could have been replaced in the meantime)
 
-        # NOTE. Item numbers are base 0 (everything else in the dfs is base 0)
-        # n_items = self.n_items #safe_length(dfs.ItemInfo)
-
-        nt = self.n_timesteps  # .NumberOfTimeSteps
-
-        items, item_numbers, time_steps = get_valid_items_and_timesteps(
-            self, items, time_steps
-        )
-
+        item_numbers = _valid_item_numbers(dfs.ItemInfo, items)
+        items = _get_item_info(dfs.ItemInfo, item_numbers)
         n_items = len(item_numbers)
 
+        self._n_timesteps = dfs.NumberOfTimeSteps
+        time_steps = _valid_timesteps(dfs, time_steps)
+
         if elements is None:
             n_elems = self.n_elements
             n_nodes = self.n_nodes
@@ -1969,13 +1966,14 @@ class Dfsu(_UnstructuredFile):
         """
 
         dfs = DfsuFile.Open(self._filename)
-        self._n_timesteps = dfs.NumberOfTimeSteps
 
-        items, item_numbers, time_steps = get_valid_items_and_timesteps(
-            self, items, time_steps=None
-        )
+        item_numbers = _valid_item_numbers(dfs.ItemInfo, items)
+        items = _get_item_info(dfs.ItemInfo, item_numbers)
         n_items = len(item_numbers)
 
+        self._n_timesteps = dfs.NumberOfTimeSteps
+        time_steps = _valid_timesteps(dfs, time_steps=None)
+
         deletevalue = self.deletevalue
 
         if isinstance(track, str):
@@ -2106,6 +2104,63 @@ class Dfsu(_UnstructuredFile):
 
         return Dataset(data_list, times, items_out)
 
+    def extract_surface_elevation_from_3d(
+        self, filename=None, time_steps=None, n_nearest=4
+    ):
+        """
+        Extract surface elevation from a 3d dfsu file (based on zn) 
+        to a new 2d dfsu file with a surface elevation item.
+
+        Parameters
+        ---------
+        filename: str
+            Output file name
+        time_steps: str, int or list[int], optional
+            Extract only selected time_steps
+        n_nearest: int, optional
+            number of points for spatial interpolation (inverse_distance), default=4
+
+        Examples
+        --------
+        >>> dfsu.extract_surface_elevation_from_3d('ex_surf.dfsu', time_steps='2018-1-1,2018-2-1')
+        """
+        # validate input
+        assert (
+            self._type == UnstructuredType.Dfsu3DSigma
+            or self._type == UnstructuredType.Dfsu3DSigmaZ
+        )
+        assert n_nearest > 0
+        time_steps = _valid_timesteps(self._source, time_steps)
+
+        # make 2d nodes-to-elements interpolator
+        top_el = self.top_elements
+        geom = self.elements_to_geometry(top_el, node_layers="top")
+        xye = geom.element_coordinates[:, 0:2]
+        xyn = geom.node_coordinates[:, 0:2]
+        tree2d = cKDTree(xyn)
+        dist, node_ids = tree2d.query(xye, k=n_nearest)
+        if n_nearest == 1:
+            weights = None
+        else:
+            weights = get_idw_interpolant(dist)
+
+        # read zn from 3d file and interpolate to element centers
+        ds = self.read(items=0, time_steps=time_steps)  # read only zn
+        node_ids_surf, _ = self._get_nodes_and_table_for_elements(
+            top_el, node_layers="top"
+        )
+        zn_surf = ds.data[0][:, node_ids_surf]  # surface
+        surf2d = interp2d(zn_surf, node_ids, weights)
+
+        # create output
+        items = [ItemInfo(EUMType.Surface_Elevation)]
+        ds2 = Dataset([surf2d], ds.time, items)
+        if filename is None:
+            return ds2
+        else:
+            title = "Surface extracted from 3D file"
+            self.write(filename, ds2, elements=top_el, title=title)
+
     def write_header(
         self, filename, start_time=None, dt=None, items=None, elements=None, title=None,
     ):
@@ -2235,10 +2290,12 @@ class Dfsu(_UnstructuredFile):
         if elements is None:
             geometry = self
         else:
-            geometry = self.elements_to_geometry(elements)
+            with warnings.catch_warnings():
+                warnings.simplefilter("ignore")
+                geometry = self.elements_to_geometry(elements)
             if (not self.is_2d) and (geometry._type == UnstructuredType.Dfsu2D):
                 # redo extraction as 2d:
-                print("will redo extraction in 2d!")
+                # print("will redo extraction in 2d!")
                 geometry = self.elements_to_geometry(elements, node_layers="bottom")
                 if items[0].name == "Z coordinate":
                     # get rid of z-item
@@ -2366,6 +2423,136 @@ class Dfsu(_UnstructuredFile):
 
         Mesh._geometry_to_mesh(outfilename, geometry)
 
+    def to_dfs2(
+        self,
+        x0: float,
+        y0: float,
+        dx: float,
+        dy: float,
+        nx: int = 20,
+        ny: int = 20,
+        rotation: float = 0,
+        epsg: typing.Optional[int] = None,
+        interpolation_method: str = "nearest",
+        filename: typing.Optional[typing.Union[str, pathlib.Path]] = None,
+    ):
+        """Export Dfsu to Dfs2 file.
+
+        Export Dfsu file to a Dfs2 file with a regular 2D grid.
+
+        Parameters
+        ----------
+        x0 : float
+            X-coordinate of the bottom left corner of the 2D grid,
+            must be in the same coordinate system as the parent Dfsu file.
+        y0 : float
+            Y-coordinate of the bottom left corner of the 2D grid,
+            must be in the same coordinate system as the parent Dfsu file.
+        dx : float
+            Grid resolution in the X direction in the units of CRS defined by `epsg`.
+        dy : float
+            Grid resolution in the Y direction in the units of CRS defined by `epsg`.
+        nx : int, optional
+            Grid size in the X direction. By default it is 20.
+        ny : int, optional
+            Grid size in the Y direction. By default it is 20.
+        rotation : float, optional
+            Grid clockwise rotation in degrees. Be default it is 0.
+        epsg : int, optional
+            EPSG identificator of coordinate system
+            in which the Dfs2 file will be created.
+            If None (default), uses coordinate system of the parent Dfsu file.
+        interpolation_method : str, optional
+            Interpolation method, by default it is 'nearest'.
+        filename : str or pathlib.Path, optional
+            Path to dfs2 file to be created.
+            If None (default), creates a temporary dfs2 file
+            in the system temporary directory.
+
+        Returns
+        -------
+        Dfs2
+            mikeio Dfs2 object pointing to the file located at `filename`.
+
+        """
+        # Process 'filename' argument
+        if filename is None:
+            filename = tempfile.NamedTemporaryFile().name + ".dfs2"
+        else:
+            if isinstance(filename, str):
+                filename = pathlib.Path(filename)
+
+            if isinstance(filename, pathlib.Path):
+                filename = filename.resolve()
+                if not filename.suffix == ".dfs2":
+                    raise ValueError(
+                        f"'filename' must point to a dfs2 file, "
+                        f"not to '{filename.suffix}'"
+                    )
+            else:
+                raise TypeError(
+                    f"invalid type in '{type(filename)}' for the 'filename' argument, "
+                    f"must be string or pathlib.Path"
+                )
+
+        # Define 2D grid in 'epsg' projection
+        grid = Grid2D(bbox=[x0, y0, x0 + dx * nx, y0 + dy * ny,], shape=(nx, ny),)
+        # TODO - create rotated grid
+        if rotation != 0:
+            raise NotImplementedError(
+                "'rotation' argument is currently not supported, "
+                "grid is assumed to have its y-axis pointing at True North"
+            )
+
+        # Determine Dfsu projection
+        # Convert X/Y points from Dfsu to 'epsg' projection
+        # TODO - infer CRS and transform between Dfsu and Dfs2 coordinate sytems
+        if epsg is not None:
+            raise NotImplementedError(
+                "'epsg' argument is currently not supported, "
+                "coordinate system is taken from the parent Dfsu file"
+            )
+
+        # Interpolate Dfsu items to 2D grid using scipy.interpolate.griddata
+        # TODO - interpolate between Dfs2 and Dfsu grids, taking into account
+        # TODO - interpolation method, CRS, and grid rotation
+        if interpolation_method != "nearest":
+            raise NotImplementedError(
+                "'interpolation_method' argument is currently not supported, "
+                "interpolation is performed using nearest neighborhood method"
+            )
+        elem_ids, weights = self.get_2d_interpolant(
+            xy=grid.xy, n_nearest=1, extrapolate=False, p=2, radius=None,
+        )
+        dataset = self.read(items=None, time_steps=None, elements=None)
+        interpolated_dataset = self.interp2d(
+            dataset, elem_ids=elem_ids, weights=weights, shape=(grid.ny, grid.nx),
+        )
+
+        interpolated_dataset = interpolated_dataset.flipud()
+
+        # Write interpolated data to 'filename'
+        dfs2 = Dfs2()
+        dfs2.write(
+            filename=str(filename),
+            data=interpolated_dataset,
+            start_time=dataset.time[0].to_pydatetime(),
+            dt=dataset.timestep,
+            items=self.items,
+            dx=grid.dx,
+            dy=grid.dy,
+            coordinate=[
+                self.projection_string,  # projection
+                grid.x0,  # origin_x
+                grid.y0,  # orign_y
+                0,  # grid orientation - TODO account for 'rotation' argument
+            ],
+            title=None,  # TODO - infer it from parent Dfsu
+        )
+
+        # Return reference to the created Dfs2 file
+        return Dfs2(filename=str(filename))
+
 
 class Mesh(_UnstructuredFile):
     def __init__(self, filename):
@@ -2387,7 +2574,7 @@ class Mesh(_UnstructuredFile):
             new z value at each node
         """
         if len(z) != self.n_nodes:
-            raise Exception(f"z must have length of nodes ({self.n_nodes})")
+            raise ValueError(f"z must have length of nodes ({self.n_nodes})")
         self._nc[:, 2] = z
         self._ec = None
 
@@ -2400,7 +2587,7 @@ class Mesh(_UnstructuredFile):
             code of each node
         """
         if len(codes) != self.n_nodes:
-            raise Exception(f"codes must have length of nodes ({self.n_nodes})")
+            raise ValueError(f"codes must have length of nodes ({self.n_nodes})")
         self._codes = codes
         self._valid_codes = None
 
